"""
TLib - مكتبة Python للتفاعل مع Telegram Bot API بسهولة وفعالية

تعتبر مكتبة TLib مكتبة Python خفيفة وسهلة الاستخدام تتيح لك التفاعل مع Telegram Bot API بشكل مباشر، 
وتوفر مجموعة من الوظائف المدمجة التي تسهل عليك تنفيذ العمليات المختلفة مثل إرسال الرسائل، 
استخراج معلومات المستخدم، والحصول على صور البروفايل وغيرها من الإجراءات التي يدعمها API الخاص بـ Telegram.

الفئة الأساسية:
    Client: فئة للتفاعل مع Telegram Bot API وتوفر وظائف متعددة مثل إرسال الرسائل واستخراج معلومات المستخدم.

الدوال المتوفرة في الفئة:
    __init__(bot_token):
        منشئ الفئة. يتم تهيئة الكائن مع توكن البوت الذي يتم استخدامه للوصول إلى API الخاص بـ Telegram.
        المعاملات:
            - bot_token (str): توكن البوت الذي تم الحصول عليه من BotFather.
    
    get_user_info_by_id(user_id):
        استخراج معلومات المستخدم بناءً على user_id.
        المعاملات:
            - user_id (int): المعرف الرقمي الخاص بالمستخدم في Telegram.
        العودة:
            - dict: استجابة JSON تحتوي على بيانات المستخدم مثل الاسم الأول، الاسم الأخير، واسم المستخدم.
    
    get_user_info_by_username(username):
        استخراج معلومات المستخدم بناءً على username (اسم المستخدم مع @).
        المعاملات:
            - username (str): اسم المستخدم الذي يبدأ بـ "@".
        العودة:
            - dict: استجابة JSON تحتوي على بيانات المستخدم مثل الاسم الأول، الاسم الأخير، واسم المستخدم.
    
    get_user_profile_photos(user_id):
        استخراج صور البروفايل للمستخدم بناءً على user_id.
        المعاملات:
            - user_id (int): المعرف الرقمي الخاص بالمستخدم في Telegram.
        العودة:
            - dict: استجابة JSON تحتوي على قائمة صور البروفايل الخاصة بالمستخدم، بما في ذلك تفاصيل كل صورة (مثل حجم الصورة وأبعادها).
    
    send_message(chat_id, text, parse_mode="HTML"):
        إرسال رسالة نصية إلى المستخدم أو المجموعة أو القناة بناءً على chat_id.
        المعاملات:
            - chat_id (int or str): يمكن أن يكون chat_id هو رقم الدردشة (للمستخدم أو المجموعة أو القناة) أو اسم المستخدم مع @.
            - text (str): النص الذي سيتم إرساله في الرسالة.
            - parse_mode (str): طريقة تنسيق النص (اختياري، الافتراضي هو "HTML"). يمكن أن تكون القيمة "HTML" أو "Markdown".
        العودة:
            - dict: استجابة JSON تحتوي على تفاصيل الرسالة المرسلة.

الفئة Client تساعدك على التفاعل مع Telegram Bot API بسهولة، حيث يمكنك إجراء العمليات التالية:

    - **get_user_info_by_id**: لاستخراج معلومات المستخدم استنادًا إلى **user_id**.
    - **get_user_info_by_username**: لاستخراج معلومات المستخدم باستخدام **username**.
    - **get_user_profile_photos**: لاستخراج صور بروفايل المستخدم باستخدام **user_id**.
    - **send_message**: لإرسال رسائل نصية إلى المستخدمين أو القنوات أو المجموعات.

المتطلبات:
    - requests: مكتبة Python لعمل طلبات HTTP إلى API الخاص بـ Telegram.

ترخيص:
    - هذا المشروع مرخص تحت MIT License.

ملاحظة:
    - تأكد من أن التوكن الذي تستخدمه صحيح.
    - بعض الوظائف قد تحتاج إلى صلاحيات معينة للبوت، تأكد من إعطاء البوت الصلاحيات اللازمة.
"""

# مثال للاستخدام:
__version__="1.0.0"
from .pytgclient import Client

# تهيئة الكائن باستخدام توكن البوت
bot = Client("YOUR_BOT_TOKEN")